@@ -1,4 +1,5 @@
 from plaid.api.api import API
+import warnings
 
 
 class PublicToken(API):
@@ -15,6 +16,22 @@ class PublicToken(API):
             'public_token': public_token,
         })
 
+    def create(self, access_token):
+        '''
+        Create a Link public_token for an API access_token.
+        (`HTTP docs <https://plaid.com/docs/api/#create-public-token>`__)
+        :param  str     access_token:
+        '''
+
+        warnings.warn(('Warning: this method will be deprecated in a future '
+                       'version. To replace the public_token for initializing '
+                       'Link, look into the link_token at '
+                       'https://plaid.com/docs/api/tokens/#linktokencreate.'))
+
+        return self.client.post('/item/public_token/create', {
+            'access_token': access_token,
+        })
+
 
 class AccessToken(API):
     '''Access token endpoints.'''
