@@ -4,11 +4,11 @@ from plaid.errors import ItemError
 from tests.integration.util import (
     create_client,
     SANDBOX_INSTITUTION,
+    START_DATE,
+    END_DATE
 )
 
 access_token = None
-START_DATE = '2020-01-01'
-END_DATE = '2021-03-15'
 
 # NOTE: Data is only generated over the past 2 years.  Ensure that the date
 # range used for transactions/get is within 2 years old
@@ -34,7 +34,7 @@ def get_transactions_with_retries(client,
                                   account_ids=None,
                                   count=None,
                                   offset=None,
-                                  num_retries=50):
+                                  num_retries=100):
     response = None
     for i in range(num_retries):
         try:
@@ -50,6 +50,8 @@ def get_transactions_with_retries(client,
                 continue
             else:
                 raise ie
+        if not response['transactions'] or not len(response['transactions']):
+            continue
         break
     return response
 
