@@ -31,3 +31,6 @@ SANDBOX_INSTITUTIONS = [
 BALANCE_INSTITUTION = 'ins_130016'
 
 WEBHOOK_VERIFICATION_KEY_ID = '6c5516e1-92dc-479e-a8ff-5a51992e0001'
+
+START_DATE = '2020-01-01'
+END_DATE = '2021-01-01'
